---
title: Some Android App Recommendations
date: 2019-05-17 17:59
author: Lynne
categories: [Personal, Technology]
tags: [Android]
---

*Update 22/05: Fedilab is now paid on Google Play.*

These are some apps that I have personally found very useful. I'll be focusing on more obscure ones rather than apps that everyone's already heard of, but I will mention a few popular ones if I feel the need to do so.

<!--more-->

I'll be using "free" in the headings to refer to the price of the app, and open or closed source afterwards to clarify. For apps with more than one price point (for example, an app with free and pro versions), I'll list both. Prices are in Australian dollars.

Some of the apps listed below are free on F-droid, but cost money on Google Play. The F-droid versions are the exact same as the Google Play ones, so you won't be missing out on any features by installing them from F-droid.

F-droid (Free, Open Source)
---------------------------

![The "Latest" page on F-droid.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-155312_F-Droid-498x1024.png)

[F-droid](https://f-droid.org/) is an alternative to Google Play, with one major difference: All apps are required to be free. This not only means "free of charge", but also [philosophically free](https://bune.city/2019/05/lynne-teaches-tech-what-is-free-software/). All F-droid apps must be released under a free open source license.

While F-droid itself is rather plain looking, and lacks quite a lot of the polish that Google Play has, its best feature is its library of truly free software. Apps from F-droid will always plainly warn the user of any potentially negative aspects (referred to as "[AntiFeatures](https://f-droid.org/wiki/page/AntiFeatures)"), such as advertisements, tracking, and non-free network dependencies. Most of these AntiFeatures are very uncommon in F-droid, with only 17 apps containing ads as of the time of writing. In total, [357 apps](https://f-droid.org/wiki/page/Category:Apps_with_antifeatures) have at least one AntiFeature.

The [F-droid Privileged Extension](https://gitlab.com/fdroid/privileged-extension/blob/master/README.md) allows F-droid to automatically install and update apps on rooted devices. With the privileged extension, F-droid behaves exactly like a regular app store on your device.

If you don't like the spartan design of F-droid, you might want to install [G-droid](https://f-droid.org/en/packages/org.gdroid.gdroid/), which provides a nicer UI with features such as recommended apps and star ratings.

![G-droid's homepage.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-161551_G-Droid-498x1024.png)

Fedilab (Free/\$3.89, Open Source)
----------------------------------

If you have an account on the [Fediverse](https://fediverse.party/), you'll probably want to install an app like [Fedilab](https://fedilab.app) (\$3.89 on [Google Play](https://play.google.com/store/apps/details?id=app.fedilab.android), Free on [F-droid](https://f-droid.org/packages/fr.gouv.etalab.mastodon/)). Fedilab allows you to manage multiple accounts across multiple instances, with support for push notifications, lists, multiple timelines, and more.

![Fedilab viewing [my main account](https://l.bune.city/me)

I've used [Tusky](https://tusky.app/) before, but I prefer Fedilab for its feature set and design. I really appreciate that it makes use of Android Oreo's [notification categories](https://developer.android.com/training/notify-user/channels), allowing the user to specify different urgency levels for different types of notifications.

Nextcloud Notes (Free/\$3.59, Open Source)
------------------------------------------

[Nextcloud Notes](https://github.com/stefan-niedermann/nextcloud-notes) (Free on [F-droid](https://f-droid.org/packages/it.niedermann.owncloud.notes/), \$3.59 on [Google Play](https://play.google.com/store/apps/details?id=it.niedermann.owncloud.notes)) is an Android client for communicating with the [Notes](https://apps.nextcloud.com/apps/notes) app for Nextcloud. It allows you to create, delete, favourite, and categorise notes on your Android device.

![Nextcloud Notes' main page.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-161811_Notes-498x1024.png)

It supports Markdown, has a dark theme, and also works with Owncloud. I use it very often to edit my shopping list, but I also have other notes that I edit from my phone, such as [this mstdn-ebooks guide](https://cloud.lynnesbian.space/s/jozbRi69t4TpD95).

Simple Gallery (Free/\$1.09, Open Source)
-----------------------------------------

[Simple Gallery](https://github.com/SimpleMobileTools/Simple-Gallery/blob/master/README.md) (Free on [F-droid](https://f-droid.org/packages/com.simplemobiletools.gallery.pro/), \$1.09 on [Google Play](https://play.google.com/store/apps/details?id=com.simplemobiletools.gallery.pro)) is part of the [Simple Mobile Tools](https://www.simplemobiletools.com/) suite. As the name implies, it is a simple gallery app.

![Simple Gallery's homepage.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-165119_Gallery-498x1024.png)

Despite the name, Simple Gallery offers a few features that many photo gallery apps don't. It supports `.nomedia`, and even allows you to add `.nomedia` to other folders through the app. It also has an internal list for excluded folders, which allows you to hide a folder from Simple Gallery while allowing it to appear in other apps. I found this feature very useful for hiding my album art from Simple Gallery without adding a `.nomedia` file to my Music folder, which would prevent my music player from scanning the folder.

It also allows you to pin folders to the top of the list, which I use to keep my screenshots and camera folders at the top. It even has a simple image editor built in, which is perfect for quickly cropping images.

![You can even set custom colours for the app!](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-170329_Gallery-498x1024.png)

LongShot (Free\*, Closed Source)
--------------------------------

\**This app contains ads and offers a \$2.99 in-app purchase to remove them.*

LongShot (Google Play) allows you to capture screenshots of long pages and automatically stitches them together. It also allows you to stitch existing images together, although the UI for doing this is rather clunky.

![Longshot's homepage.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-170810_LongShot-498x1024.png)

The "auto scroll" mode makes the app scroll down the page for you, automatically capturing images as it goes, and presenting you with a finished product at the end. I recommend this app if you often find yourself wanting to screenshot something that's too long to fit on one phone screen.

See here for an example screenshot captured with LongShot.

K-9 Mail (Free, Open Source)
----------------------------

[K-9 Mail](https://k9mail.github.io/) ([F-droid](https://f-droid.org/packages/com.fsck.k9/), [Google Play](https://play.google.com/store/apps/details?id=com.fsck.k9)) is an email client for Android. It offers support for multiple inboxes, push notifications (this is the reason I switched from Gmail - the Gmail app only supports push notifications from Gmail accounts, even if your other accounts support IMAP push), filters, PGP encryption, and more.

![K-9's accounts page.](https://wasabi.lynnesbian.space/bune-city/2019/05/image-16-498x1024.png)

It also supports a "unified inbox" view, for viewing emails from all your inboxes at once. Different inboxes are given different colour strips, and these colours can be customised.

![The unified inbox view.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-172737_K-9_Mail-498x1024.png)

Its design feels rather archaic, and feels like a KitKat app. K-9's design is remarkably similar to Gmail's Holo theme from half a decade ago.

![Gmail's Holo theme.](https://cdn.appstorm.net/android.appstorm.net/files/2012/05/screen08.jpg)

While I miss some of Gmail's convenience features (mainly being able to swipe an email to mark it as unread), I prefer K-9 in almost every other way. Except the design, anyway.

Simon Tatham's Puzzles (Free, Open Source)
------------------------------------------

[Simon Tatham's Puzzles](https://chris.boyle.name/projects/android-puzzles) ([Google Play](https://play.google.com/store/apps/details?id=name.boyle.chris.sgtpuzzles), [GitHub](https://github.com/chrisboyle/sgtpuzzles)) is an Android port of the rather verbosely named [Simon Tatham's Portable Puzzle Collection](https://www.chiark.greenend.org.uk/~sgtatham/puzzles/).

![The game selection screen.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-173324_Puzzles-498x1024.png)

Puzzles is a collection of simple puzzles and games such as Sudoku and Minesweeper. It contains no ads, offers save and load capabilities with autosave on exit, allows for multiple difficulty settings, and is compatible with saves created by the PC version.

![Sudoku, known as "solo" in the app.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-174131_Puzzles-498x1024.png)

Puzzles should run on almost any Android device, with a minimum required version of Android 4.1 (Jelly Bean).

Automate (Free\*, Closed Source)
--------------------------------

*\*The free version is limited to 30 blocks per flow. I bought the full version for \$3.49, but the price may have changed since then.*

Automate (Google Play) allows you to automate tasks on your phone using an intuitive interface where action blocks are combined to create flows.

![Automate flow for mailing clipboard contents.](https://wasabi.lynnesbian.space/bune-city/2019/05/Screenshot_20190517-175403_Automate-498x1024.png)

You can access all sorts of things, from accelerometer readings to notifications to Google Drive files. Automate is frequently updated, both to maintain compatibility with newer Android versions, and to add new blocks. It also offers some blocks that work with rooted devices.

